disease.database.dynamodb
=========================

.. automodule:: disease.database.dynamodb
   :members:
   :undoc-members:
   :special-members: __init__
   :exclude-members: model_fields, model_config
